logholmVersion = "1.0.2"
logholmVersionCodename = "California"
logholmVersionPrefix = "stable"

stdMsgList = [
["info", "information", "Information"], 
["scs", "success", "Success"], 
["dbg", "debug", "Debug"], 
["warn", "warning", "Warning"], 
["err", "error", "Error"], 
["crt", "critical", "Critical"]]